#!/bin/bash
set -ue

module load nco


# todo: rename version_ids

# Attributes
TITLE="MPI-ESM1-2 output prepared for PalMod2"
REFERENCES="Kapsch, M.-L., Mikolajewicz, U., Ziemen, F., & Schannwell, C. (2022). Ocean response in transient simulations of the last deglaciation dominated by underlying ice-sheet reconstruction and method of meltwater distribution. Geophysical Research Letters, 49, e2021GL096767. https://doi.org/10.1029/2021GL096767\nMPI-ESM: Mauritsen, T. et al. (2019), Developments in the MPI‐M Earth System Model version 1.2 (MPI‐ESM1.2) and Its Response to Increasing CO2, J. Adv. Model. Earth Syst.,11, 998-1038, doi:10.1029/2018MS001400,\nMueller, W.A. et al. (2018): A high‐resolution version of the Max Planck Institute Earth System Model MPI‐ESM1.2‐HR. J. Adv. Model. EarthSyst.,10,1383–1413, doi:10.1029/2017MS001217"
NOMINAL_RESOLUTION="500 km"
SOURCE="MPI-ESM1.2-CR (2017): \naerosol: none, prescribed Kinne (2010)\natmos: ECHAM6.3 (spectral T31; 96 x 48 longitude/latitude; 31 levels; top level 10 hPa)\natmosChem: none\nland: JSBACH3.20\nlandIce: none/prescribed\nocean: MPIOM1.63 (bipolar GR3.0, approximately 300km; 122 x 101 longitude/latitude; 40 levels; top grid cell 0-15 m)\nocnBgchem: none\nseaIce: unnamed (thermodynamic (Semtner zero-layer) dynamic (Hibler 79) sea ice model)\nsolidLand: none/prescribed"
CONVENTIONS="CF-1.7 PalMod-2.0"
CREATION_DATE="2022-02-22T22:00:00Z"
HISTORY="2022-02-22T22:00:00Z ; CMOR rewrote data to be consistent with PalMod2, CF-1.7 PalMod-2.0 and CF standards."
declare -A TABLE_INFO
TABLE_INFO[Amon]="Creation Date:(14 February 2022) MD5:26bac4b397da7babac4e36561826e6b0"
TABLE_INFO[Omon]="Creation Date:(14 February 2022) MD5:26bac4b397da7babac4e36561826e6b0"
TABLE_INFO[Lmon]="Creation Date:(14 February 2022) MD5:26bac4b397da7babac4e36561826e6b0"
TABLE_INFO[dec]="Creation Date:(14 February 2022) MD5:26bac4b397da7babac4e36561826e6b0"
TABLE_INFO[fx]="Creation Date:(14 February 2022) MD5:26bac4b397da7babac4e36561826e6b0"
TABLE_INFO[Ofx]="Creation Date:(14 February 2022) MD5:26bac4b397da7babac4e36561826e6b0"
#TABLE_INFO[]=
declare -A VARIANT_INFO
VARIANT_INFO["1"]="Predecessor model version to p2. p2 contains a range of bug fixes and an updated model tuning: it comprises the introduction of a brine plume parameterization in MPI-OM and a modification of sea-ice lead closure parameters, improvement of the automated topography generation scripts (e.g. baroclinic exchange in shallow fjords), and a replacement of the direct use of topographic roughness in ECHAM6 by a parameterized treatment like the one in the standard ECHAM6 model. Tuning parameters are taken from Mauritsen and Roeckner (2020) and comprise the surface value of the critical humidity profile for cloud formation (crs), the threshold between cloud water and ice (csecfrl) and the fall speed of cloud ice (cvtfall). Additionally, a mean volcanic aerosol forcing was taken into account. For details see Supporting Information of Kapsch et al., 2022."
VARIANT_INFO["2"]="For details see Supporting Information of Kapsch et al., 2022."
VARIANT_INFO["3"]="Equivalent to p2 but with a different model tuning. For details see Supporting Information of Kapsch et al., 2022."
echo "------------------------"
echo $TITLE
echo $REFERENCES
echo $NOMINAL_RESOLUTION
echo $SOURCE
echo $CONVENTIONS
echo $CREATION_DATE
echo $HISTORY
echo ${TABLE_INFO[@]}
echo "-------------------------"

#exp_id=transient-deglaciation-prescribed-ice6g_r1i1p1f1-CR
exp_id=transient-deglaciation-prescribed-glac1d_r1i1p1f1-CR
ifolder=/work/bk1192/k204212/palmod/${exp_id}/archive/PalMod2/
#ifolder=/work/ik1017/ESGF_Buff/k204212/PalMod2_test

ifiles=($(find $ifolder -type f))
echo ${#ifiles[@]} files found.
i=0
for ifile in ${ifiles[@]}; do
i=$((i+1))
echo $i $ifile
    table=$(echo $ifile | rev | cut -d '/' -f 1 | rev | cut -d '_' -f 2)
    memberid=$(echo $ifile | rev | cut -d '/' -f 1 | rev | cut -d '_' -f 5)
    physics_index=${memberid:5:1}

    # Run ncatted
    ncatted -O -h -a variant_info,global,m,c,"${VARIANT_INFO[$physics_index]}" -a history,global,m,c,"$HISTORY" -a creation_date,global,m,c,"$CREATION_DATE" -a physics_index,global,m,c,"$physics_index" -a variant_label,global,m,c,"$memberid" -a table_info,global,m,c,"${TABLE_INFO[$table]}" -a Conventions,global,m,c,"$CONVENTIONS" -a title,global,m,c,"$TITLE" -a references,global,m,c,"$REFERENCES" -a source,global,m,c,"$SOURCE" -a nominal_resolution,global,m,c,"$NOMINAL_RESOLUTION" $ifile || echo "ERROR $ifile"
    #ncatted -O -h -a variant_info,global,m,c,"${VARIANT_INFO[$physics_index]}" $ifile || echo "ERROR $ifile"

    # Adjust filename timestamp
    if [[ "$table" != *"fx"* ]]; then
        trunk=$(echo $ifile | rev | cut -d '_' -f 2- | rev)
        timestamp=$(echo $ifile | rev | cut -d '.' -f 2 | cut -d '_' -f 1 | rev)
        time1=$(echo $timestamp | cut -d '-' -f 1 | sed 's/^0*//' )
        time2=$(echo $timestamp | cut -d '-' -f 2 | sed 's/^0*//' )
        echo $time1 $time2
        # Case 1 - Decadal data
        if [[ "$table" == *"dec"* ]]; then
            if [[ "${time1: -1}" == "5" ]]; then
                newtime1=$(printf "%05d" $(expr $time1 - 4))
                newtime2=$(printf "%05d" $(expr $time2 + 5))
            else
                newtime1=$(printf "%05d" ${time1} )
                newtime2=$(printf "%05d" ${time2} )
            fi
        # Case 2 - the rest - annual and monthly data
        elif [[ "$table" == *"mon"* ]]; then
            newtime1=$(printf "%07d" ${time1} )
            newtime2=$(printf "%07d" ${time2} )
        elif [[ "$table" == *"yr"* ]]; then
            newtime1=$(printf "%05d" ${time1} )
            newtime2=$(printf "%05d" ${time2} )
        elif [[ "$table" == *"day"* ]]; then
            newtime1=$(printf "%09d" ${time1} )
            newtime2=$(printf "%09d" ${time2} )
        elif [[ "$table" == *"hr"* ]]; then
            newtime1=$(printf "%011d" ${time1} )
            newtime2=$(printf "%011d" ${time2} )
        else
            echo "ERROR: ${table}: no timestamp renaming rule!"
            continue
        fi
        # mv command
        ifile_new=${trunk}_${newtime1}-${newtime2}.nc
        [[ "$ifile" != "$ifile_new" ]] && {
            mv -v $ifile $ifile_new || echo "ERROR renaming $ifile to $ifile_new"
        }
    fi
done
