#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable vegFrac / table Emon
# Editor Note: Sum up all tiles. Provide for all years only if dynveg=true; otherwise for the 1st year only.
{ (if_requested $member $srfmod Emon vegFrac $chunk && {
  find_file -e            "$sdir" "slm_nan_${period}" ifile1
  find_file -e            "$sdir" "veg_ratio_max_mon_${period}*" ifile2
  $cdo -f nc -O \
    expr,'vegFrac=vertsum(var20)/slm;' \
    -merge -selname,slm $ifile1 -selname,var20 $ifile2 \
    ${sdir}/out_diag/Emon_vegFrac_$period.nc || echo ERROR
}; )&; }>$err.vegFrac.Emon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable frivera / table Lmon
# Editor Note: disch, multiplication with density of water 1000 kg m-3 to attain kg m-2 s-1 out of m s-1
{ (if_requested $member $srfmod Lmon frivera $chunk && {
  find_file -e            "$sdir" "*_jsbach_jsbach_mm_${period}*" ifile
  $cdo -f nc -O \
    expr,'frivera=1000*var218;' \
    $ifile ${sdir}/out_diag/Lmon_frivera_$period.nc || echo ERROR
}; )&; }>$err.frivera.Lmon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable grassFrac / table Lmon
# Editor Note: sum grass tiles (7,8)
{ (if_requested $member $srfmod Lmon grassFrac $chunk && {
  find_file -e            "$sdir" "box_cover_fract_mon_${period}*" ifile1
  find_file -e            "$sdir" "slm_nan_${period}" ifile2
  $cdo -f nc -O \
    expr,'grassFrac=vertsum(sellevidxrange(var12,7,8))/slm;' \
    -merge -selname,var12 $ifile1 -selname,slm $ifile2 \
    ${sdir}/out_diag/Lmon_grassFrac_$period.nc || echo ERROR
}; )&; }>$err.grassFrac.Lmon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable landCoverFrac / table Lmon
# Editor Note: apply c3/c4-crop-mask, veg_ratio_max and glacier mask, to separate all 14 PFTs. Provide for all years only if dynveg=true; otherwise for the 1st year only.
{ (if_requested $member $srfmod Lmon landCoverFrac $chunk && {
  # Insert here your custom diagnostics. Per default an external placeholder script is being included.
  . ${SCRIPT_ROOT}/incl_mod_jsbach/c6_diag_Lmon_landCoverFrac_jsbach.h
}; )&; }>$err.landCoverFrac.Lmon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable mrso / table Lmon
# Editor Note: sum up all layers. Is it not ECHAM6 var140*1000?
{ (if_requested $member $srfmod Lmon mrso $chunk && {
  find_file -e            "$sdir" "*_jsbach_mm_${period}*" ifile
  $cdo -f nc -O \
    expr,'mrso=1000*vertsum(var84);' \
    $ifile ${sdir}/out_diag/Lmon_mrso_$period.nc || echo ERROR
}; )&; }>$err.mrso.Lmon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable shrubFrac / table Lmon
# Editor Note: sum up shrub tiles (5,6). Provide for all years only if dynveg=true; otherwise for the 1st year only.
{ (if_requested $member $srfmod Lmon shrubFrac $chunk && {
  find_file -e            "$sdir" "box_cover_fract_mon_${period}*" ifile1
  find_file -e            "$sdir" "slm_nan_${period}" ifile2
  $cdo -f nc -O \
    expr,'shrubFrac=vertsum(sellevidxrange(var12,5,6))/slm;' \
    -merge -selname,var12 $ifile1 -selname,slm $ifile2 \
    ${sdir}/out_diag/Lmon_shrubFrac_$period.nc || echo ERROR
}; )&; }>$err.shrubFrac.Lmon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable treeFrac / table Lmon
# Editor Note: sum up tree tiles (1,2,3,4). Provide for all years only if dynveg=true; otherwise for the 1st year only.
{ (if_requested $member $srfmod Lmon treeFrac $chunk && {
  find_file -e            "$sdir" "box_cover_fract_mon_${period}*" ifile1
  find_file -e            "$sdir" "slm_nan_${period}" ifile2
  $cdo -f nc -O \
    expr,'treeFrac=vertsum(sellevidxrange(var12,1,4))/slm;' \
    -merge -selname,var12 $ifile1 -selname,slm $ifile2 \
    ${sdir}/out_diag/Lmon_treeFrac_$period.nc || echo ERROR
}; )&; }>$err.treeFrac.Lmon 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable sftlf / table dec
{ (if_requested $member $srfmod dec sftlf $chunk && {
  find_file -e            "$sdir" "*_jsbach_jsbach_mm_${period}*" ifile
  $cdo -f nc -O \
    yearmean \
    -selcode,25 $ifile \
    ${sdir}/tmp_diag/dec_sftlf_$period.nc || echo ERROR
  if_requested $member $srfmod dec sftlf $chunk '???0123124' && {
    eval $cdo -O ensmean \
      ${sdir}/tmp_diag/dec_sftlf_{$((period-9))..${period}}.nc ${sdir}/out_diag/dec_sftlf_${period}.nc && \
      eval rm ${sdir}/tmp_diag/dec_sftlf_{$((period-9))..${period}}.nc || echo ERROR
}; }; )&; }>$err.sftlf.dec 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable areacellr / table fx
{ (if_requested $member $srfmod fx areacellr $chunk && {
  find_file -e            "$sdir" "*_hd_higres_mon_${period}*" ifile
  $cdo -f nc -O \
    expr,'areacellr=gridarea(friv);' \
    $ifile ${sdir}/out_diag/fx_areacellr.nc || echo ERROR
}; )&; }>$err.areacellr.fx 2>&1

#-- Diagnostic for jsbach (ESM: MPI-ESM1-2) variable mrsofc / table fx
{ (if_requested $member $srfmod fx mrsofc $chunk && {
  find_file -e            "$sdir" "aggr_fx_mrsofc_${period}.nc" ifile
  $cdo -f nc -O \
    expr,'mrsofc=soil_field_cap*soil_depth*1.e+3;' \
    $ifile ${sdir}/out_diag/fx_mrsofc.nc || echo ERROR
}; )&; }>$err.mrsofc.fx 2>&1

